@@ -17,5 +17,9 @@ def cola(snt:str="I love you."):
 	''' cola '''
 	return requests.get(f"http://{apihost}/cola", params={"snt":snt}).json()[0]['cola'] #http://cpu76.wrask.com:8000/cola?snt=I%20love%20you.&host=172.17.0.1%3A8003
 
+def semdis(cands:str="orange/banana", given:str="apple", sepa:str='/'): 
+	''' 2022.1.5 ''' 
+	return requests.post(f'http://hw6.jukuu.com:8002/gensim/distance/words?src={given}', json=cands.strip().split(sepa)).json() 
+
 if __name__	== '__main__': 
-	print (gramcnt())
\ No newline at end of file
+	print (semdis())
\ No newline at end of file
