@@ -25,33 +25,13 @@ def adjust_by_wordlist(snt, mkf):
 			print(">>adjust_by_wordlist Ex:", ex, "\t|", snt)
 			exc_type, exc_value, exc_traceback_obj = sys.exc_info()
 			traceback.print_tb(exc_traceback_obj)
-			#redis.r.hset(f"debug:{id}", "ex:_adjust_by_wordlist", json.dumps([ str(ex), traceback.format_tb(exc_traceback_obj)]) )
 
 def snt_mkf(snts, docs, sntdic:dict={}, ibeg_byte:bool=False, diffmerge:bool=False, batch:int=0, dskhost:str="172.17.0.1:7095") :  
-	''' multiple process, ie: batch sent count in one shot=16,  added 2022.4.7 '''
-	import grequests
+	''' NO grequests, 2022.11.30  '''
 	inputs = mkf_inputs(snts, docs, sntdic, diffmerge)
-
-	if batch <= 0: # single process, tranditional way 
-		mkfs	= requests.post(f"http://{dskhost}/parser", data={"q":json.dumps(inputs).encode("utf-8")}).json()
-		if ibeg_byte: [adjust_by_wordlist(snt,mkf) for snt,mkf in zip(snts, mkfs)]
-		return dict(zip(snts, mkfs))
-
-	req_list = []
-	offset = 0 
-	while offset < len(inputs): 
-		req_list.append( grequests.post(f"http://{dskhost}/parser", data={"q":json.dumps(inputs[offset:offset+batch]).encode("utf-8")}) )
-		offset = offset + batch
-
-	res_list = grequests.map(req_list)
-	dic = {}
-	for res in res_list: 	
-		for ar in res.json(): #[{"feedback":{"_punct_space@w_punct.space_extra":{"cate":"w_punct.space_extra",
-			snt = ar.get('meta',{}).get('snt','')
-			if snt: 
-				dic[snt] = ar 
-				if ibeg_byte: adjust_by_wordlist(snt, ar)
-	return dic 
+	mkfs   = requests.post(f"http://{dskhost}/parser", data={"q":json.dumps(inputs).encode("utf-8")}).json()
+	if ibeg_byte: [adjust_by_wordlist(snt,mkf) for snt,mkf in zip(snts, mkfs)]
+	return dict(zip(snts, mkfs))
 
 def sntmkf(snt:str, gec:str, diffmerge:bool=False, dskhost:str="172.17.0.1:7095" ): 
 	''' snt -> mkf, for debug only '''
@@ -145,4 +125,32 @@ def test():
 
 if __name__ == '__main__':
 	import fire 
-	fire.Fire({"test":test, "uvirun":uvirun, "hello": lambda: sntsmkf(asdsk=False, ), 'feedbacks': lambda: feedbacks()}) 
\ No newline at end of file
+	fire.Fire({"test":test, "uvirun":uvirun, "hello": lambda: sntsmkf(asdsk=False, ), 'feedbacks': lambda: feedbacks()}) 
+
+'''
+def snt_mkf0(snts, docs, sntdic:dict={}, ibeg_byte:bool=False, diffmerge:bool=False, batch:int=0, dskhost:str="172.17.0.1:7095") :  
+	# multiple process, ie: batch sent count in one shot=16,  added 2022.4.7 
+	import grequests
+	inputs = mkf_inputs(snts, docs, sntdic, diffmerge)
+
+	if batch <= 0: # single process, tranditional way 
+		mkfs	= requests.post(f"http://{dskhost}/parser", data={"q":json.dumps(inputs).encode("utf-8")}).json()
+		if ibeg_byte: [adjust_by_wordlist(snt,mkf) for snt,mkf in zip(snts, mkfs)]
+		return dict(zip(snts, mkfs))
+
+	req_list = []
+	offset = 0 
+	while offset < len(inputs): 
+		req_list.append( grequests.post(f"http://{dskhost}/parser", data={"q":json.dumps(inputs[offset:offset+batch]).encode("utf-8")}) )
+		offset = offset + batch
+
+	res_list = grequests.map(req_list)
+	dic = {}
+	for res in res_list: 	
+		for ar in res.json(): #[{"feedback":{"_punct_space@w_punct.space_extra":{"cate":"w_punct.space_extra",
+			snt = ar.get('meta',{}).get('snt','')
+			if snt: 
+				dic[snt] = ar 
+				if ibeg_byte: adjust_by_wordlist(snt, ar)
+	return dic 
+'''
\ No newline at end of file
