@@ -1,13 +1,14 @@
+# 2023.2.7 add tag_span
 # 2022.7.4 merge verbnet and terms code  | # 2022.5.28, redisgears's python is 3.7 , to be compatible | # 2022.3.20, usage:  import en |  spacy.nlp("hello")   
 import json,spacy,os,builtins,time,fileinput, sqlite3,traceback,sys
-from spacy.tokens import DocBin,Doc,Token
-from spacy.tokenizer import Tokenizer
+from spacy.tokens import DocBin,Doc,Token,SpanGroup
 from spacy.language import Language
 from spacy.matcher import Matcher,DependencyMatcher
 
 def custom_tokenizer(nlp): #https://stackoverflow.com/questions/58105967/spacy-tokenization-of-hyphenated-words
 	from spacy.lang.char_classes import ALPHA, ALPHA_LOWER, ALPHA_UPPER, CONCAT_QUOTES, LIST_ELLIPSES, LIST_ICONS
 	from spacy.util import compile_infix_regex
+	from spacy.tokenizer import Tokenizer
 	infixes = (
 		LIST_ELLIPSES
 		+ LIST_ICONS
@@ -26,8 +27,6 @@ def custom_tokenizer(nlp): #https://stackoverflow.com/questions/58105967/spacy-t
 
 if not hasattr(spacy, 'nlp'):
 	spacy.nlp		= spacy.load(os.getenv('spacy_model','en_core_web_lg')) # 3.4.1
-	#spacy.tobs		= to_docbin # for old codes
-	#spacy.frombs	= from_docbin
 	spacy.from_json = lambda arr: Doc(spacy.nlp.vocab).from_json(arr) # added 2022.8.19
 	spacy.nlp.tokenizer = custom_tokenizer(spacy.nlp)	#nlp.tokenizer.infix_finditer = infix_re.finditer
 	#print([t.text for t in nlp("It's 1.50, up-scaled haven't")]) # ['It', "'s", "'", '1.50', "'", ',', 'up-scaled', 'have', "n't"]
@@ -41,6 +40,13 @@ def phrase_matcher( rules ={'pp':[[{'POS': 'ADP'},{"POS": {"IN": ["DET","NUM","A
 	[matcher.add(name, pats,  greedy ='LONGEST') for name, pats in rules.items()]
 	return matcher
 
+def DepMatcher(rules:dict = {"svo":[ {"RIGHT_ID": "v",  "RIGHT_ATTRS": {"POS": "VERB"}}, {"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "subject", "RIGHT_ATTRS": {"DEP": "nsubj"}},{"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "object","RIGHT_ATTRS": {"DEP": "dobj"}  }],} ):
+	'''  [(spacy.nlp.vocab[name].text, ar) for name, ar in matcher(doc)]  #[('svo', [1, 0, 2])]'''
+	from spacy.matcher import DependencyMatcher
+	matcher = DependencyMatcher(spacy.nlp.vocab)
+	[matcher.add(name, [pattern]) for name, pattern in rules.items() ]
+	return matcher 
+
 def sntbr(essay, trim:bool=False, with_pid:bool=False): 
 	''' added 2022.5.28 '''
 	from spacy.lang import en
@@ -72,6 +78,7 @@ simple_sent		= lambda doc:  len([t for t in doc if t.pos_ == 'VERB' and t.dep_ !
 compound_snt	= lambda doc:  len([t for t in doc if t.dep_ == 'conj' and t.head.dep_ == 'ROOT']) > 0
 snt_source		= lambda sid, doc: {'type':'snt', 'src': sid, 'snt':doc.text, 'pred_offset': pred_offset(doc), 	'postag':'_^ ' + ' '.join([f"{t.text}_{t.lemma_}_{t.pos_}_{t.tag_}" if t.text == t.text.lower() else f"{t.text}_{t.text.lower()}_{t.lemma_}_{t.pos_}_{t.tag_}" for t in doc]) + ' _$',  'tc': len(doc)}
 pred_offset		= lambda doc: ( ar := [ t.i for t in doc if t.dep_ == "ROOT"], offset := ar[0] if len(ar) > 0 else 0, offset/( len(doc) + 0.1) )[-1]
+has_zh			= lambda s : any([c for c in s if ord(c) > 255])
 
 def show(doc):
 	''' used in the notebook, for debug '''
@@ -265,7 +272,6 @@ def merge_clause(doc): # subtree of a verb is the clause , https://subscription.
 
 @Language.component("span_clause")
 def span_clause(doc): # {'cl:4': [that it cried], 'cl:10': [that I would fail]}
-	from spacy.tokens import SpanGroup
 	for v in [t for t in doc if t.pos_ == 'VERB' and t.dep_ != 'ROOT' ] : # non-root
 		try:
 			children = list(v.subtree)
@@ -635,6 +641,43 @@ def toktrp(doc): # basic for sqlsi
 			arr.extend([f"{doc[ibeg].lemma_}:{doc[ibeg].pos_}:{name}:{doc[ibeg].lemma_} {doc[ibeg+1].lemma_} {doc[ibeg+2].text}", f"{doc[ibeg].lemma_}:{doc[ibeg].pos_}:{name}", f"*:{doc[ibeg].pos_}:{name}"])
 	return arr 
 
+isNP	= lambda t: t.ent_type_ == 'NP' and ' ' in t.text # len > 1 
+doctoks = lambda doc: ['<s>'] + [ f"_{t.pos_}" if t.pos_ in ('PROPN','NUM','CD','X','SPACE') else "_NP" if isNP(t) else t.text.lower()  for t in doc ]
+def ngram(toks, n:int=3): 
+	ts = set() 
+	tlen =  len(toks)
+	for i in range( tlen ): 
+		for j in range(n): 
+			if i+j < tlen: 
+				ts.add( " ".join(toks[i:i+j]) )
+	return [t for t in ts if t and not '.' in t]
+
+def c4get(grams:list=['<s> is','jumped over _NP'], name='c4gram'):  
+	if not hasattr(c4get,name): setattr( c4get, name, sqlite3.connect(f"/data/model/c4/{name}.si", check_same_thread=False) )  
+	return { row[0] : row[1] for row in getattr(c4get, name).execute("select s,i from si where s in ('"+"','".join([k for k in grams if not "'" in k])+"')") } 
+
+def ngram_check(text:str="The quick fox jumped over the lazy dog.", n:int=3):
+	doc = spacy.nlp(text)
+	merge_np(doc) 
+	toks	= doctoks(doc)
+	grams	= ngram(toks, n)
+	dic		= c4get(grams) 
+	return [ {"gram": w, "cnt": dic.get(w,0) } for w in chk]
+
+def gram(doc, n:int=7):
+	ts = set() 
+	def count(toks, ts, n): # ts: set 
+		tlen =  len(toks)
+		for i in range( tlen ): 
+			for j in range(n): 
+				if i+j < tlen: 
+					ts.add( " ".join(toks[i:i+j]) )
+
+	count( doctoks(doc), ts, n) 
+	merge_np(doc) 
+	count( doctoks(doc), ts, n) 
+	return "|".join([t for t in ts if t])
+
 def sqlconn(outfile, sqls:str=["create table if not exists si( s varchar(64) not null primary key, i int not null default 0) without rowid","create table if not exists st( s varchar(64) not null primary key, t text, cnt int not null default 0) without rowid"]):
 	conn  =	sqlite3.connect(outfile, check_same_thread=False) 
 	for sql in sqls: conn.execute(sql)
@@ -744,69 +787,223 @@ def es_submit(infile, index:str=None, batch=200000, recreate:bool=True, host='17
 	if actions : helpers.bulk(client=es,actions=actions, raise_on_error=False)
 	print(">>load finished:" , infile, index )
 
+# vnp:make use of
+postag_func_kp = {  # doc,start, end, tag 
+	"prmods": lambda d,s,e,tag:d.user_data.update({f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [d[e-1].lemma_ + f":VERB:prmods|" + d[s].lemma_ + " " + d[s+1:e-1].text.lower(), d[e-1].lemma_ + f":VERB|prmods"], "tags": ' '.join([t.tag_ for t in d[s:e]]) }}) , 
+	"VP": lambda d,s,e,tag: d.user_data.update({f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [d[s].lemma_ + f":{d[s].pos_}:VP|" + d[s].lemma_ + " " + d[s+1:e].text.lower(), d[s].lemma_ + f":{d[s].pos_}|VP"],  "tags": ' '.join([t.tag_ for t in d[s:e]])}}) , 
+	"PP": lambda d,s,e,tag: d.user_data.update({f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [d[e-1].lemma_ + f":{d[e-1].pos_}:PP|" + d[s:e].text.lower(), d[e-1].lemma_ + f":{d[e-1].pos_}|PP"], "tags": ' '.join([t.tag_ for t in d[s:e]])}}) ,
+	"AP": lambda d,s,e,tag: d.user_data.update({f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [d[e-1].lemma_ + f":{d[e-1].pos_}:AP|" +  d[s:e].text, d[e-1].lemma_ + f":{d[e-1].pos_}|AP"],  "tags": ' '.join([t.tag_ for t in d[s:e]])}}) ,
+	"vpn": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s].lemma_}:VERB:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vpn", f"{d[s].lemma_}:VERB:vpn|{d[s].lemma_} {d[s+1].text} _NOUN",
+				f"{d[e-1].lemma_}:NOUN:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[e-1].lemma_}:NOUN|vpn", f"{d[e-1].lemma_}:NOUN:vpn|_VERB {d[s+1:e].text}"]} }) , # _VERB with force, jump over the dog? 
+	"bpn": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s].lemma_}:VERB:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vpn", f"{d[s].lemma_}:VERB:vpn|{d[s].lemma_} {d[s+1].text} _NOUN",
+			f"{d[e-1].lemma_}:NOUN:vpn|{d[s].lemma_} {d[s+1:e].text}", f"{d[e-1].lemma_}:NOUN|vpn", f"{d[e-1].lemma_}:NOUN:vpn|_VERB {d[s+1:e].text}"] }}) , # be with force, be is a VERB
+	"vnp": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s].lemma_}:VERB:vnp|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vnp", f"{d[s].lemma_}:VERB:vnp|{d[s].lemma_} _NOUN {d[s+2].text}",
+				f"{d[s+1].lemma_}:NOUN:vnp|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:NOUN|vnp", f"{d[s+1].lemma_}:NOUN:vnp|_VERB {d[s+1:e].text}"]}}) ,
+	"vp":  lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s].lemma_}:VERB:vp|{d[s].lemma_} {d[s+1].text}", f"{d[s].lemma_}:VERB|vp", f"{d[s+1].lemma_}:{d[s+1].pos_}:vp|_VERB {d[s+1].text}"] }}) ,
+	"vpp": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s].lemma_}:VERB:vpp|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vpp"] }}) ,
+	"vpg": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s].lemma_}:VERB:vpg|{d[s].lemma_} {d[s+1].text}", f"{d[s].lemma_}:VERB|vpg", f"{d[s].lemma_}:VERB:vpg|_{d[s].lemma_} {d[s+1].text} _VBG"] }}) ,
+	"pn":  lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s+1].lemma_}:NOUN:pn|{d[s:e].text.lower()}", f"{d[s+1].lemma_}:NOUN|pn"] }}) ,
+	"pnp": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s+1].lemma_}:NOUN:pnp|{d[s:e].text.lower()}", f"{d[s+1].lemma_}:NOUN:pnp"] }}) ,
+	"bapv": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s+1].lemma_}:ADJ:bapv|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:ADJ|bapv", f"{d[s+1].lemma_}:ADJ:bapv|_{d[s].lemma_} {d[s+1:e-1].text} _VERB"]}}) ,  
+	"batv": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s+1].lemma_}:ADJ:batv|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:ADJ|batv", f"{d[s+1].lemma_}:ADJ:batv|_{d[s].lemma_} {d[s+1:e-1].text} _VERB"]}}) ,  
+	"bepv": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s+1].lemma_}:VERB:bepv|{d[s].lemma_} {d[s+1:e].text}",f"{d[s+1].lemma_}:VERB|bepv", f"{d[s+1].lemma_}:VERB:bepv|_be {d[s+1:e-1].text} _VERB"]}}) , # _be forced to _VERB
+	"betv": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s+1].lemma_}:VERB:betv|{d[s].lemma_} {d[s+1:e].text}",f"{d[s+1].lemma_}:VERB|betv", f"{d[s+1].lemma_}:VERB:betv|_be {d[s+1:e-1].text} _VERB"]}}) , # _be forced to _VERB
+	"bap": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s+1].lemma_}:ADJ:bap|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:ADJ|bap"]}}) ,
+	"bep": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s+1].lemma_}:VERB:bep|{d[s].lemma_} {d[s+1:e].text}", f"{d[s+1].lemma_}:VERB|bep"]}}) ,
+	"vop": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s].lemma_}:VERB:vop|{d[s].lemma_} oneself {d[e-1].text}", f"{d[s].lemma_}:VERB|vop",  f"{d[s].lemma_}:VERB:vop|_{d[s].lemma_} _oneself {d[e-1].text}"]}}) ,
+	"vtv": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s].lemma_}:VERB:vtv|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB:vtv|_{d[s].lemma_} {d[s+1:e-1].text} _VERB", f"{d[s].lemma_}:VERB|vtv", f"{d[e-1].lemma_}:VERB|~vtv", f"{d[e-1].lemma_}:VERB:~vtv|{d[s].lemma_}"]}} ) ,
+	"vg": lambda d,s,e,tag: d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s].lemma_}:VERB:vg|{d[s].lemma_} {d[e-1].text}", f"{d[s].lemma_}:VERB:vg|_{d[s].lemma_} _VBG", f"{d[s].lemma_}:VERB|vg", f"{d[e-1].lemma_}:VERB|~vg", f"{d[e-1].lemma_}:VERB:~vg|{d[s].lemma_}"]}}) , 
+	"vdpg": lambda d,s,e,tag:d.user_data.update({ f"{tag}:{d[s].lemma_} {d[s+1:e].text.lower()}[{s},{e})":
+		{"nac": [f"{d[s].lemma_}:VERB:vdpg|{d[s].lemma_} {d[s+1:e].text}", f"{d[s].lemma_}:VERB|vdpg", f"_{d[s].lemma_} {d[s+1:e-1].text} _VBG"] }}),
+	}
+
+def postag_match(doc, func=lambda doc,start,end,tag: doc.spans.update({f"postag[{start},{end}):{tag}": SpanGroup(doc, name=tag, spans=[ doc[start : end] ], attrs={}) } ) ): 
+	''' doc.spans[f"span[{start},{end}):{tag}"] = SpanGroup(doc, | add matched new span by phrase rules, 2023.2.6 '''
+	if not hasattr(postag_match, 'matcher'):  	
+		postag_match.matcher = phrase_matcher({
+		"prmods":[[{"POS": {"IN": ["AUX","VERB"]}},{"POS": {"IN": ["ADV"]}, "OP": "*"}, {"POS": {"IN": ["ADJ","VERB"]}, "OP": "*"},{"POS": {"IN": ["PART","ADP","TO"]}, "OP": "*"},{"POS": 'VERB'}]], # could hardly wait to meet
+		"VP":  [[{'POS': 'VERB'},{"POS": {"IN": ["DET","ADP","ADJ"]}, "OP": "*"},{"POS": 'NOUN'}, {"POS": {"IN": ["ADP","TO"]}, "OP": "*"}], [{'POS': 'VERB'},{"POS": {"IN": ["DET","ADP","ADJ","TO","PART"]}, "OP": "*"},{"POS": 'VERB'}]], # wait to meet
+		"PP":  [[{'POS': 'ADP'},{"POS": {"IN": ["DET","NUM","ADJ",'PUNCT','CONJ']}, "OP": "*"},{"POS": {"IN": ["NOUN","PART"]}, "OP": "+"}]],    
+		"AP":  [[{"POS": {"IN": ["ADV"]}, "OP": "+"}, {"POS": 'ADJ'}]],  
+		"vpn": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"POS":"ADP"} , {"TAG":"NN", "IS_LOWER":True}]],  # come into force 
+		"bpn": [[{"LEMMA":"be"}, {"POS":"ADP"} , {"TAG":"NN"}]],  # be in force => vpn 
+		"vnp": [[{"POS":"VERB"}, {"TAG":"NN"}, {"POS":"ADP"} ]],  # make use of, lay emphasis on
+		"vp": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"POS":"ADP"} ]],  # abide by | distinguish from
+		"vpp": [[{"POS":"VERB"}, {"POS":"ADP"}, {"POS":"ADP"} ]], # live up to
+		"vpg": [[{"POS":"VERB"}, {"POS":"ADP"}, {"TAG":"VBG","DEP":"pcomp"} ]], # insisted on going
+		"pn": [[{"POS":"ADP", "DEP":"prep"} , {"TAG":"NN", "DEP":"pobj"}]],  # by force
+		"pnp": [[{"POS":"ADP", "DEP":"prep"} , {"TAG":"NN", "DEP":"pobj"}, {"POS":"ADP", "DEP":"prep"}]],  # on account of
+		"bapv": [[{"LEMMA":"be"} , {"TAG":{"IN": ["JJ"]}}, {"POS":"ADP"}, {"POS":"VERB"}]],  # 
+		"batv": [[{"LEMMA":"be"} , {"TAG":{"IN": ["JJ"]}}, {"LEMMA":"to"}, {"POS":"VERB"}]],  
+		"bepv": [[{"LEMMA":"be"} , {"TAG":{"IN": ["VBN"]}}, {"POS":"ADP"}, {"POS":"VERB"}]],  # be forced of going / ? bepv? 
+		"betv": [[{"LEMMA":"be"} , {"TAG":{"IN": ["VBN"]}}, {"LEMMA":"to"}, {"TAG":"VB"}]],  # be considered to be/go
+		"bap": [[{"LEMMA":"be"} , {"TAG":{"IN": ["JJ"]}}, {"POS":"ADP"}]], #be ignorant of
+		"bep": [[{"LEMMA":"be"} , {"TAG":{"IN": ["VBN"]}}, {"POS":"ADP"}]],  # be forced to
+		"vop": [[{"POS":"VERB"} , {"TEXT": {"REGEX": "[a-z]+self$"}}, {"POS":"ADP"}]], #throw oneself into
+		"vtv": [[{"POS":"VERB"}, {"LEMMA":"to"}, {"POS":"VERB", "DEP":"xcomp"} ]], 
+		"vg": [[{"POS":"VERB"},  {"TAG":"VBG", "DEP":"xcomp"} ]], 
+		"vdpg": [[{"POS":"VERB"},  {"POS":"ADV"} ,  {"POS":"ADP"} ,  {"TAG":"VBG"} ]],  # look forward to seeing
+		})
+	for name, start, end in postag_match.matcher(doc):
+		try:
+			tag = spacy.nlp.vocab[name].text
+			if isinstance(func, dict): # tag -> lambda 
+				func[tag](doc, start, end, tag) if tag in func else print("Invalid tag:", tag, doc[start:end].text) 
+			else: 
+				func(doc, start, end, tag)  # is a functor, #doc.spans[f"postag[{start},{end}):{tag}"] = SpanGroup(doc, name=tag, spans=[ doc[start : end] ], attrs={}) #attrs = {"pos": v.pos_, "tag": v.tag_, "dep": v.dep_, "lemma":v.lemma_, "ent_type": "S." + v.dep_ } 
+		except Exception as e:
+			print ("postag_match ex:", e, name, start, end) 
+
+def skenp_match(doc, func=lambda doc,start,end,tag: doc.spans.update({f"skenp[{start},{end}):{tag}": SpanGroup(doc, name=tag, spans=[ doc[start : end] ], attrs={}) } )): 
+	if not hasattr(skenp_match, 'matcher'): skenp_match.matcher = phrase_matcher({
+	"vnpN": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"ENT_TYPE":"NP"}, {"POS":{"IN": ["ADP"]}}, {"ENT_TYPE":"NP"}]],  # remind _NP of _NP , bring _NP to life
+	"vnpn": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"ENT_TYPE":"NP"}, {"POS":{"IN": ["ADP"]}}, {"TAG":"NN"}]],  # take _NP into account
+	"vpnpn": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"POS":{"IN": ["ADP"]}}, {"ENT_TYPE":"NP"}, {"POS":{"IN": ["ADP"]}}, {"ENT_TYPE":"NP"}]],  # vary from _NP to _NP 
+	"vnpe": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"ENT_TYPE":"NP"}, {"TAG":"IN"}, {"TAG":"VBN"}]],  # take _NP for/as granted
+	"vppn": [[{"POS":"VERB"}, {"POS":"ADP"}, {"POS":"ADP"}, {"ENT_TYPE":"NP"} ]],  # live up to _NP
+	"vdpn": [[{"POS":"VERB"}, {"POS":"ADV"}, {"POS":"ADP"}, {"ENT_TYPE":"NP"} ]],  # look back on _NP 
+	"vpnn": [[{"POS":"VERB"}, {"POS":"ADP"}, {"TAG":"NOUN"}, {"ENT_TYPE":"NP"} ]],  # I keep in mind the interconnectedness.
+	"vn": [[{"POS":"VERB"}, {"ENT_TYPE":"NP"} ]], 
+	"vnn": [[{"POS":"VERB"}, {"ENT_TYPE":"NP"}, {"ENT_TYPE":"NP"} ]], 
+	"vna": [[{"POS":"VERB"}, {"ENT_TYPE":"NP"}, {"POS":"ADJ"} ]], 
+	"vne": [[{"POS":"VERB"}, {"ENT_TYPE":"NP"}, {"TAG":"VBN"} ]], # leave it kept 
+	"vntb": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"ENT_TYPE":"NP"}, {"LEMMA":"to"} , {"LEMMA":"be"}]], # consider _NP _NP | _NP _ADJ | _NP to be 
+	"vntv": [[{"POS":"VERB","TAG": {"NOT_IN": ["VBN"]}}, {"ENT_TYPE":"NP"}, {"LEMMA":"to"} , {"POS":"VERB"}]], # _force _NP to _VERB
+	"vntbn": [[{"POS":"VERB"}, {"ENT_TYPE":"NP"}, {"LEMMA":"to"} , {"LEMMA":"be"}, {"ENT_TYPE":"NP"}]], 
+	"vntba": [[{"POS":"VERB"}, {"ENT_TYPE":"NP"}, {"LEMMA":"to"} , {"LEMMA":"be"}, {"POS":"ADJ"}]],
+	"vdpn": [[{"POS":"VERB"},  {"POS":"ADV"} ,  {"POS":"ADP"} ,  {"ENT_TYPE":"NP"} ]],  # look forward to _NP | a bright future 
+	})
+	for name, start, end in skenp_match.matcher(doc):
+		try:
+			tag = spacy.nlp.vocab[name].text
+			if isinstance(func, dict): # tag -> lambda 
+				func[tag](doc, start, end, tag) if tag in func else print("Invalid tag:", tag, doc[start:end].text) 
+			else: 
+				func(doc, start, end, tag) # doc.spans[f"skenp[{start},{end}):{tag}"] = SpanGroup(doc, name=tag, spans=[ doc[start : end] ], attrs={}) #attrs = {"pos": v.pos_, "tag": v.tag_, "dep": v.dep_, "lemma":v.lemma_, "ent_type": "S." + v.dep_ } 
+		except Exception as e:
+			print ("skenp_match ex:", e, name, start, end) 
+			exc_type, exc_value, exc_obj = sys.exc_info() 	
+			traceback.print_tb(exc_obj)
+
+def trp3_match(doc, func=lambda doc,i,j,k,tag: doc.spans.update({f"trp3[{i},{j},{k}]:{tag}": SpanGroup(doc, name=tag, spans=[ doc[i:i+1], doc[j:j+1], doc[k:k+1] ], attrs={"tag":tag, "i":i,"j":j, "k":k}) } )):
+	if not hasattr(trp3_match, 'matcher'): 
+		trp3_match.matcher = DepMatcher({
+		"dobj-advmod":[ {"RIGHT_ID": "v",  "RIGHT_ATTRS": {"POS": "VERB"}},{"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "n","RIGHT_ATTRS": {"DEP": "dobj"}  }, {"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "adv", "RIGHT_ATTRS": {"DEP": "advmod"}}], # the last one , is the ADV 
+		"dobj-amod":  [ {"RIGHT_ID": "v",  "RIGHT_ATTRS": {"POS": "VERB"}},{"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "n","RIGHT_ATTRS": {"DEP": "dobj"}  }, {"LEFT_ID": "n", "REL_OP": ">", "RIGHT_ID": "a", "RIGHT_ATTRS": {"DEP": "amod"}}], # 1,4,3  the last one is the adj 
+		"nba":[ {"RIGHT_ID": "v","RIGHT_ATTRS": {"LEMMA": "be"}},{"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "subject", "RIGHT_ATTRS": {"DEP": "nsubj", "POS":"NOUN"}},{"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "object","RIGHT_ATTRS": {"DEP": "acomp"}}],  # fate is good, film:NOUN:nba:ADJ
+		"nbn":[ {"RIGHT_ID": "v","RIGHT_ATTRS": {"LEMMA": "be"}},{"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "subject", "RIGHT_ATTRS": {"DEP": "nsubj", "POS":"NOUN"}},{"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "object","RIGHT_ATTRS": {"DEP": "attr", "POS":"NOUN"}}],  # scene is a story
+		"nbc":[ {"RIGHT_ID": "v","RIGHT_ATTRS": {"LEMMA": "be"}},{"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "subject", "RIGHT_ATTRS": {"DEP": "nsubj"}},{"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "cl","RIGHT_ATTRS": {"DEP": "ccomp"}}],  # you are what you read
+		"advcl-acomp":[ {"RIGHT_ID": "v",  "RIGHT_ATTRS": {"POS": "VERB"}}, {"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "clv", "RIGHT_ATTRS": {"DEP": "advcl"}},{"LEFT_ID": "clv", "REL_OP": ">", "RIGHT_ID": "object","RIGHT_ATTRS": {"DEP": "acomp"}}],  # "While I was thrilled that it cried, I worried that I would fail.
+		"dobj-prt":  [ {"RIGHT_ID": "v",  "RIGHT_ATTRS": {"POS": "VERB"}},{"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "prt","RIGHT_ATTRS": {"DEP": "prt"}  }, {"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "n", "RIGHT_ATTRS": {"DEP": "dobj", "POS":"NOUN","IS_ALPHA":True,"IS_LOWER":True}}], # turn off the radio 
+		"vpN": [ {"RIGHT_ID": "v",  "RIGHT_ATTRS": {"POS": "VERB","IS_ALPHA":True}},{"LEFT_ID": "v", "REL_OP": ">", "RIGHT_ID": "prep","RIGHT_ATTRS": {"DEP": "prep","IS_LOWER":True,"IS_ALPHA":True}  }, {"LEFT_ID": "prep", "REL_OP": ">", "RIGHT_ID": "n", "RIGHT_ATTRS": {"DEP": "pobj", "POS":"NOUN","IS_ALPHA":True}}], # jump over the dog, diff from come into force/NN
+		})  # nbe? nbx = nba + nbe + nbn
+	for name, ar in trp3_match.matcher(doc):
+		try:
+			tag = spacy.nlp.vocab[name].text
+			i,j,k = ar[0:3] 
+			if isinstance(func, dict): # tag -> lambda 
+				func[tag](doc, i, j, k, tag) if tag in func else print("Invalid tag:", tag, i,j,k )
+			else: 
+				func(doc, i, j, k, tag) # doc.spans[f"trp3[{i},{j},{k}]:{tag}"] = SpanGroup(doc, name=tag, spans=[ doc[i:i+1], doc[j:j+1], doc[k:k+1] ], attrs={"tag":tag, "i":i,"j":j, "k":k}) 
+		except Exception as e:
+			print ("trp3_match ex:", e, name, ar) 
+
+span_NP = lambda sp: " ".join([ "_NP" if t.ent_type_ == 'NP' else t.text.lower() for t in sp]) #else f"_{t.tag_}" if t.tag_ in ('VBN')
+def skenp_func_kp(doc, start, end, tag): # skenp_func_kp	= lambda doc, start, end, tag: doc.user_data.update({f"{tag}:{doc[start].lemma_} " + span_NP(doc[start+1:end]) : {"vlem":doc[start].lemma_, "start":start, "end":end, "nac": [f"{doc[start].lemma_}:VERB:{tag}|" +span_NP(doc[start:end] ), f"{doc[start].lemma_}:VERB|{tag}", f"*:VERB|{tag}"]} }) 
+	nac = [f"{doc[start].lemma_}:VERB:{tag}|" +span_NP(doc[start:end] ), f"{doc[start].lemma_}:VERB|{tag}", f"*:VERB|{tag}"]
+	if tag in ('vnpn'): # take _NP into account, added 2023.2.14
+		nac.extend([f"{doc[end-1].text.lower()}:NOUN:{tag}|" +doc[start].lemma_ + " " + span_NP(doc[start+1:end-1]) + " " + doc[end-1].text.lower(), f"{doc[end-1].text.lower()}:NOUN|{tag}", f"*:NOUN|{tag}"])
+	if tag in ("vnpe"): # take _NP for granted
+		nac.extend([f"{doc[end-1].lemma_}:VERB:{tag}|" +span_NP(doc[start:end]), f"{doc[end-1].lemma_}:VERB|{tag}", f"*:VERB|{tag}"])
+	doc.user_data.update({f"{tag}:{doc[start].lemma_} " + span_NP(doc[start+1:end]) : {"vlem":doc[start].lemma_, "start":start, "end":end, "nac":nac} })
+
+trp3_func_kp = { #drink:VERB:dobj:NOUN:water:amod:ADJ safe
+	"dobj-advmod":	lambda doc, i, j, k, tag:  doc.user_data.update({f"dobj-advmod:{doc[k].text} {doc[i].lemma_} {doc[j].lemma_}[{i},{j},{k}]": {"tag":tag, "from":"trp3" ,
+						"nac":[f"{doc[i].lemma_}:{doc[i].pos_}:{doc[j].dep_}:{doc[j].pos_}:{doc[j].lemma_}:{doc[k].dep_}-{doc[k].pos_}|{doc[k].lemma_}",f"{doc[i].lemma_}:{doc[i].pos_}:{doc[j].dep_}:{doc[j].pos_}:{doc[j].lemma_}|{doc[k].dep_}-{doc[k].pos_}"]}}), 
+	"dobj-amod":	lambda doc, i, j, k, tag:  doc.user_data.update({f"dobj-amod:{doc[i].lemma_} {doc[j].text} {doc[k].lemma_}[{i},{j},{k}]": {"tag":tag, "from":"trp3" ,
+						"nac":[f"{doc[i].lemma_}:{doc[i].pos_}:{doc[j].dep_}:{doc[j].pos_}:{doc[j].lemma_}:{doc[k].dep_}-{doc[k].pos_}|{doc[k].lemma_}",f"{doc[i].lemma_}:{doc[i].pos_}:{doc[j].dep_}:{doc[j].pos_}:{doc[j].lemma_}|{doc[k].dep_}-{doc[k].pos_}"]}}), 
+	"nba":			lambda doc, i, j, k, tag:  doc.user_data.update({f"nba:{doc[j].lemma_} {doc[k].text}[{i},{j},{k}]":{"tag":tag, "from":"trp3", # when there is no ambi, no need to add ~ 
+						"nac":[f"{doc[j].lemma_}:{doc[j].pos_}:{tag}|{doc[k].lemma_}",f"{doc[j].lemma_}:{doc[j].pos_}|{tag}",f"{doc[k].lemma_}:{doc[k].pos_}:{tag}|{doc[j].lemma_}",f"{doc[k].lemma_}:{doc[k].pos_}|{tag}"]}}), 
+	"nbn":			lambda doc, i, j, k, tag:  doc.user_data.update({f"nbn:{doc[j].lemma_} {doc[k].lemma_}[{i},{j},{k}]":{"tag":tag, "from":"trp3",
+						"nac":[f"{doc[j].lemma_}:{doc[j].pos_}:{tag}|{doc[k].lemma_}",f"{doc[j].lemma_}:{doc[j].pos_}|{tag}",f"{doc[k].lemma_}:{doc[k].pos_}:~{tag}|{doc[j].lemma_}",f"{doc[k].lemma_}:{doc[k].pos_}|~{tag}"]}}), 
+	"nbc":			lambda doc, i, j, k, tag:  doc.user_data.update({f"nbc:{doc[j].lemma_} _CL[{i},{j},{k}]":{"tag":tag, "from":"trp3",
+						"nac":[f"{doc[j].lemma_}:{doc[j].pos_}|{tag}"]}}), 
+	"advcl-acomp":	lambda doc, i, j, k, tag:  doc.user_data.update({f"advcl-acomp:{doc[i].lemma_} {doc[k].text}[{i},{j},{k}]":{"tag":tag, "from":"trp3",
+						"nac":[f"{doc[i].lemma_}:{doc[i].pos_}:advcl-acomp|{doc[k].text.lower()}",f"{doc[k].text.lower()}:{doc[k].tag_ if doc[k].tag_ == 'VBN' else doc[k].pos_}:~advcl-acomp|{doc[i].lemma_}",f"{doc[i].lemma_}:{doc[i].pos_}|advcl-acomp",f"{doc[k].text.lower()}:{doc[k].tag_ if doc[k].tag_ == 'VBN' else doc[k].pos_}|~advcl-acomp"]}}), 
+	"dobj-prt":		lambda doc, i, j, k, tag:  doc.user_data.update({f"dobj-prt:{doc[i].lemma_}_{doc[j].lemma_} {doc[k].lemma_}[{i},{j},{k}]":{"tag":tag, "from":"trp3",
+						"nac":[f"{doc[i].lemma_}_{doc[j].lemma_}:{doc[i].pos_}:dobj:{doc[k].pos_}|{doc[k].lemma_}",f"{doc[k].lemma_}:{doc[k].pos_}:~dobj:{doc[i].pos_}|{doc[i].lemma_}_{doc[j].lemma_}",f"{doc[i].lemma_}_{doc[j].lemma_}:{doc[i].pos_}|dobj:{doc[k].pos_}",f"{doc[k].lemma_}:{doc[k].pos_}|~dobj:{doc[i].pos_}"]}}), 
+	"vpN":			lambda doc, i, j, k, tag:  doc.user_data.update({f"vpN:{doc[i].lemma_} {doc[j].text} {doc[k].text}[{i},{j},{k}]":{"tag":tag, "from":"trp3", # jump over the dog / come into force/vpn 
+						"nac":[f"{doc[i].lemma_}:{doc[i].pos_}:vpN|{doc[k].lemma_}",f"{doc[i].lemma_}:{doc[i].pos_}|vpN",f"{doc[k].lemma_}:{doc[k].pos_}:vpN|{doc[i].lemma_} {doc[j].lemma_} {doc[k].lemma_}",f"{doc[k].lemma_}:{doc[k].pos_}|vpN"]}}), 
+	}
+
+def kp_born(doc, base:bool=True):
+	''' born kp to user_data ,  NNS:knowledges,  nbe:fate sealed,  '''
+	from dic.wordlist import wordlist 
+	if base:
+		[ doc.user_data.update({f"{t.pos_}:{t.lemma_}[{t.i}]": {"type":"tok", 
+				"nac":[f"{t.pos_}|{t.lemma_}", f"{t.lemma_}|{t.pos_}", f"*|{t.pos_}", f"{t.lemma_}:{t.pos_}|{t.tag_}",f"*:{t.pos_}|{t.tag_}", f"{t.lemma_}:{t.pos_}:{t.tag_}|{t.text.lower()}"]}, 
+			f"{t.tag_}:{t.text.lower()}[{t.i}]": {"type":"tok", 
+				"nac":[f"{t.tag_}|{t.text.lower()}", f"*|{t.tag_}"]} }) for t in doc if t.pos_ in ("NOUN","VERB","ADJ","ADV") and t.is_alpha ]
+
+		[ doc.user_data.update({f"nbe:{t.lemma_} {t.head.text.lower()}[{t.head.i},{t.i}]": {"type":"trp",
+			'nac':[f"{t.lemma_}:{t.pos_}:nbe|{t.head.text.lower()}", f"{t.lemma_}:{t.pos_}|nbe", f"*:{t.pos_}|nbe",  # Smoking is banned. /VBG
+				f"{t.head.text.lower()}:{t.tag_}:nbe|{t.lemma_}", f"{t.head.text.lower()}:{t.tag_}|nbe", f"*:{t.tag_}|nbe",] } }) for t in doc if t.dep_ == 'nsubjpass' and t.head.tag_ == 'VBN' ] # the fate is sealed  / smiling is banned .
+		[ doc.user_data.update({f"vc:{t.head.lemma_}[{t.head.i},{t.i}]": {"type":"trp", 'nac':[f"{t.head.lemma_}:{t.head.pos_}|vc", f"*:{t.head.pos_}|vc"] } }) for t in doc if t.dep_ == 'ccomp' and t.head.pos_ == 'VERB' ]
+		[ doc.user_data.update({f"ROOT-{t.tag_}:{t.lemma_}[{t.i}]": {"type":"trp","nac":[f"{t.lemma_}:{t.pos_}|ROOT"]} }) for t in doc if t.dep_ == 'ROOT' ]
+		[ doc.user_data.update({f"xcomp-{t.head.pos_}-{t.tag_}:{t.head.lemma_} {t.text}[{t.head.i},{t.i}]": {"type":"trp", 
+			"nac":[f"{t.head.lemma_}:{t.head.pos_}|xcomp:{t.tag_}", f"{t.head.lemma_}:{t.head.pos_}:xcomp:{t.tag_}|{t.text.lower()}",
+				   f"{t.lemma_}:{t.tag_}|~xcomp:{t.head.pos_}", f"{t.lemma_}:{t.tag_}:~xcomp:{t.head.pos_}|{t.head.lemma_}", 
+			       f"{t.lemma_}:{t.pos_}|~xcomp:{t.head.pos_}", f"{t.lemma_}:{t.pos_}:~xcomp:{t.head.pos_}|{t.head.lemma_}", # added 203.2.26
+				   f"*:{t.head.pos_}|xcomp:{t.tag_}", f"*:{t.pos_}|~xcomp:{t.head.pos_}",] } }) 
+			for t in doc if t.dep_ == 'xcomp' and t.pos_ == 'VERB' ]
+		[ doc.user_data.update({f"NP:{sp.text.lower()}[{sp.start},{sp.end})": {"type":"chunk", 
+			"nac":[f"{doc[sp.end-1].lemma_}:{doc[sp.end-1].pos_}:NP|{sp.text.lower()}", f"{doc[sp.end-1].lemma_}:{doc[sp.end-1].pos_}|NP"
+			, f"*:{doc[sp.end-1].pos_}|NP"] }}  ) 
+			for sp in doc.noun_chunks] #NP:a book
+
+		# add triple kp: dobj-VERB-NOUN:open door
+		[ doc.user_data.update({f"{t.dep_}-{t.head.pos_}-{t.pos_}:{t.head.lemma_} {t.lemma_}[{t.head.i},{t.i}]": {"type":"trp",
+			"nac":[f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}|{t.pos_}",f"{t.head.lemma_}:{t.head.pos_}|{t.dep_}:{t.pos_}", f"{t.head.lemma_}:{t.head.pos_}:{t.dep_}:{t.pos_}|{t.lemma_}",
+				   f"{t.lemma_}:{t.pos_}:~{t.dep_}|{t.head.pos_}", f"{t.lemma_}:{t.pos_}|~{t.dep_}:{t.head.pos_}", f"{t.lemma_}:{t.pos_}:~{t.dep_}:{t.head.pos_}|{t.head.lemma_}",
+				   f"*:{t.head.pos_}|{t.dep_}",f"*:{t.pos_}|~{t.dep_}",
+			] } }) 
+			for t in doc if t.pos_ in ("NOUN","VERB","ADJ","ADV","ADP") and t.dep_ not in ('ROOT','punct','xcomp') and t.is_alpha and t.head.is_alpha and t.lemma_ in wordlist  and t.head.lemma_ in wordlist]
+
+	postag_match(doc, postag_func_kp) 
+	trp3_match(doc, trp3_func_kp)
+	merge_np(doc)  
+	skenp_match(doc, skenp_func_kp)  #on_span(doc, skenp_func, 'skenp[')
+	return doc.user_data
+
 [setattr(builtins, k, v) for k, v in globals().items() if not k.startswith("_") and not '.' in k and not hasattr(builtins,k) ] #setattr(builtins, "spacy", spacy)
 if __name__	== '__main__': 
-	#es_submit("gzjc.jsonlg.3.4.1.gz", host='hw13.jukuu.com')
-	import fire
-	fire.Fire({"sqlsi":sqlsi, "test":test, "es_submit":es_submit, "fasttext":fasttext })
-
-def kps(doc): 
-	''' doc is of single sent, 2022.9.8 '''
-	_kps = []
-	[ _kps.append(f"{t.pos_}:{t.lemma_}") for t in doc]  # VERB:book
-	[ _kps.append(f"_{t.lemma_}:{t.text.lower()}") for t in doc]  # _book:booked,  added 2022.8.21
-	[ _kps.append(f"{t.tag_}:{t.pos_}_{t.lemma_}") for t in doc]  # VBD:VERB_book,  added 2022.8.25
-	[ _kps.append(f"{t.dep_}:{t.head.pos_}_{t.head.lemma_}:{t.pos_}_{t.lemma_}") for t in doc if t.pos_ not in ('PUNCT')]  # 
-	[ _kps.append(f"~{t.dep_}:{t.pos_}_{t.lemma_}:{t.head.pos_}_{t.head.lemma_}") for t in doc if t.pos_ not in ('PUNCT')]  # 
-	[ _kps.append(f"NP:{doc[sp.end-1].pos_}_{doc[sp.end-1].lemma_}:{sp.text.lower()}") for sp in doc.noun_chunks ]
-	_kps.append( f"stype:" +  "simple_snt" if simple_sent(doc) else "complex_snt" )
-	if compound_snt(doc) : _kps.append("stype:compound_snt")
-
-	# [('pp', 'on the brink', 2, 5), ('ap', 'very happy', 9, 11)]
-	for lem, pos, type, chunk in kp_matcher(doc): #brink:NOUN:pp:on the brink
-		_kps.append(f"{type}:{pos}_{lem}:{chunk}")
-	for trpx, row in dep_matcher(doc): #[('svx', [1, 0, 2])] ## consider:VERB:vnpn:**** 
-		verbi = row[0] #consider:VERB:be_vbn_p:be considered as
-		_kps.append(f"{trpx}:{doc[verbi].pos_}_{doc[verbi].lemma_}")
-		if trpx == 'sva' and doc[row[0]].lemma_ == 'be': # fate is sealed, added 2022.7.25   keep sth. stuck
-			_kps.append(f"sbea:{doc[row[1]].pos_}_{doc[row[1]].lemma_}:{doc[row[2]].pos_}_{doc[row[2]].lemma_}")
-		
-	# last to be called, since NP is merged
-	for row in verbnet_matcher(doc): #[(1, 0, 3, 'NP V S_ING')]
-		if len(row) == 4: 
-			verbi, ibeg, iend, chunk = row
-			if doc[verbi].lemma_.isalpha() : 
-				_kps.append(f"verbnet:{doc[verbi].pos_}_{doc[verbi].lemma_}:{chunk}")
-
-	for name,ibeg,iend in post_np_matcher(doc): #added 2022.7.25
-		if name in ('v_n_vbn','v_n_adj'): 
-			_kps.append(f"{name}:{doc[ibeg].pos_}_{doc[ibeg].lemma_}:{doc[ibeg].lemma_} {doc[ibeg+1].lemma_} {doc[ibeg+2].text}")
-	return _kps
-
-
-def to_docbin(doc):
-	doc_bin= spacy.tokens.DocBin()
-	doc_bin.add(doc)
-	return doc_bin.to_bytes()
-
-def from_docbin(bs): 
-	return list(spacy.tokens.DocBin().from_bytes(bs).get_docs(spacy.nlp.vocab))[0] if bs else None
-
-def model(name:str='sm'):
-	''' sm/md/lg, doc = en.model('lg')("hello world"),  2023.1.17 '''
-	if not hasattr(model, name):  
-		setattr(model, name, spacy.load(f'en_core_web_{name}') )
-	return getattr(model, name) 
-lookup	= lambda s, name='lg': model(name).vocab[s].text
-fromjson= lambda jsons, name='lg': Doc(model(name).vocab).from_json(jsons)
-
-def getdoc(snt, bs):  # execute("GET", f"bytes:{snt}") 
-	return Doc(spacy.nlp.vocab).from_bytes(bs) if bs else spacy.nlp(snt) 
+	import fire, platform
+	[ print ( kp, item) for kp, item in kp_born(spacy.nlp("I take it into account.")).items()]  if platform.system() in ('Windows') else fire.Fire({"sqlsi":sqlsi, "test":test, "es_submit":es_submit, "fasttext":fasttext })
 
 #print(sntbr("[\u8bd1\u6587]The 55-kilometre Hong Kong Zhuhai-Macau Bridge is an extraordinary engineering. It is the world's longest sea-crossing transportation system combining bridges and tunnels, which joins the three cities of Hong Kong Zhuhai and Macao, cutting the travelling time among them from 3 hours to 30 minutes. The reinforced concrete bridge with huge spans fully not only proves that China has the ability to complete the record-breaking mega-construction, but also will enhance the regional integration and boost the economic growth. It plays a crucial role in the overall plan to develop China’s Great Bay Area, which China intends to turn into one rivaling those of San Francisco, New York and Tokyo in terms of technological innovation and economic prosperity.", with_pid=True))
 #c:\users\zhang\appdata\local\programs\python\python38\lib\site-packages  
 #/home/ubuntu/.local/lib/python3.8/site-packages/en
-
 '''
 >>> model('lg').vocab
 <spacy.vocab.Vocab object at 0x0000013459154A60>
