@@ -4,6 +4,7 @@ import json, traceback,sys, time, fire,os,traceback,fileinput,en, pymysql
 
 #brink:NOUN:pp:on the brink
 get_pp	= lambda doc: [ f"{type}_" + chunk.replace(' ','_') for lem, pos, type, chunk in en.kp_matcher(doc) if type in ('pp')]
+# consider_VERB_svc
 
 def get_kps(doc): 
 	kps = [ f"{t.lemma_}_{t.pos_}" for t in doc  if t.pos_ not in ('PUNCT')] + [ f"{t.lemma_}_{t.pos_}_{t.tag_}" for t in doc  if t.pos_ not in ('PUNCT')] + get_pp(doc) + [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp','oprd')]
@@ -34,13 +35,13 @@ def get_kps(doc):
 
 def run(infile, host:str='172.17.0.1', port:int=3309, db:str='nac'):
 	'''  '''
-	name = infile.split('.jsonlg')[0] 
+	name = infile.split('.jsonlg' if '.jsonlg' in infile else '.')[0] 
 	start = time.time()
 	my_conn = pymysql.connect(host=host,port=port,user='root',password='cikuutest!',db=db)
 	print ("started:", infile , my_conn,  flush=True)
 	with my_conn.cursor() as cursor: 
 		cursor.execute(f"drop TABLE if exists {name}_snt")
-		cursor.execute(f"CREATE TABLE if not exists {name}_snt(sid int primary key, snt text not null, kps text not null, map JSON, frames text,  fulltext key `snt`(`snt`), fulltext key `kps`(`kps`), fulltext key `frames`(`frames`) ) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
+		cursor.execute(f"CREATE TABLE if not exists {name}_snt(sid bigint primary key, snt text not null, kps text not null, map JSON, frames text,  fulltext key `snt`(`snt`), fulltext key `kps`(`kps`), fulltext key `frames`(`frames`) ) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
 		for sid, line in enumerate(fileinput.input(infile,openhook=fileinput.hook_compressed)):  #for rowid, snt, doc in tqdm(Spacybs(dbfile).docs()) :
 			try:
 				arr = json.loads(line.strip()) 
@@ -57,4 +58,24 @@ def run(infile, host:str='172.17.0.1', port:int=3309, db:str='nac'):
 	print(f"{infile} is finished, \t| using: ", time.time() - start) 
 
 if __name__	== '__main__':
-	fire.Fire(run)
\ No newline at end of file
+	fire.Fire(run)
+
+'''
+	def fts(self, infile, name:str=None):
+		if name is None: name = infile.split('/')[-1].split('.jsonlg')[0] 
+		cursor.execute(f"drop TABLE if exists {name}_snt")
+		cursor.execute(f"CREATE TABLE if not exists {name}_snt(sid bigint primary key, snt text not null, kps text not null, fulltext key `snt`(`snt`), fulltext key `kps`(`kps`) ) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
+		for did, line in enumerate(fileinput.input(infile,openhook=fileinput.hook_compressed)): 
+			try:
+				arr = json.loads(line.strip()) 
+				tdoc = spacy.from_json(arr) 
+				for sid, sp in enumerate(tdoc.sents):
+					doc = sp.as_doc()
+					cursor.execute(f"insert ignore into {name}_snt(sid, snt, kps) values(%s, %s, %s)", (did * 10000 + sid,sp.text.strip(), 
+						" ".join([ f"{t.lemma_}_{t.pos_}" for t in doc  if t.pos_ not in ('PUNCT')] 
+						+ [ f"{t.lemma_}_{t.pos_}_{t.tag_}_{t.text.lower()}" for t in doc  if t.pos_ not in ('PUNCT')] # consider:VERB:VBG:considering
+						+ get_pp(doc) # added 2022.12.3
+						+ [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp','oprd')]) ))
+			except Exception as e:
+				print ("ex:", e, did, line) 
+'''
\ No newline at end of file
