@@ -3,8 +3,11 @@ import streamlit as st
 st.set_page_config(layout='wide')
 from common import * 
 
-rid	= st.experimental_get_query_params().get('rid', [0])[0] 
-uid = st.experimental_get_query_params().get('uid', ['0'])[0]
+params = st.experimental_get_query_params() 
+params = {k: v[0] if isinstance(v, list) else v for k, v in params.items()}
+
+rid = params.get('rid', 0)
+uid = params.get('uid', 0)
 
 st.sidebar.header( hget(f"config:rid-{rid}", "title", f"i+1 写作智慧课堂") + f"[{rid}]" )
 st.sidebar.caption(uid.split(',')[-1])  
