@@ -85,6 +85,7 @@ config = {
 			"_source": {"excludes": ["md5"]},
 			"properties": {
 			 "@timestamp":{"format":"strict_date_optional_time||epoch_millis", "type":"date"},
+			 "ddate":{"type": "date", "format": "strict_date_optional_time||yyyy-MM-dd HH:mm:ss||epoch_millis"}, 
 			"errs": { "type": "text", "analyzer": "path_ana" ,"fielddata":"true" },
 			"feedback": { "type": "text", "analyzer": "feedback_ana" ,"fielddata":"true" },
 			"kps": { "type": "text", "analyzer": "path_ana3" ,"fielddata":"true" },
@@ -122,6 +123,7 @@ config = {
 			"ver": { "type": "integer"},
 			"ct": { "type": "integer"},
 			"lem": { "type": "keyword"},
+			"frame": { "type": "keyword"}, # flair/frame 
 			"lempos": { "type": "keyword"}, # for wordattr , ie: open/VERB 
 			"lex": { "type": "keyword"},
 			"low": { "type": "keyword"},
@@ -273,6 +275,7 @@ config = {
 			"v": { "type": "keyword",  "index": "false"},
 			"n": { "type": "keyword",  "index": "false"},
 			"adj": { "type": "keyword",  "index": "false"},
+			"sent": { "type": "keyword",  "index": "false"},
 			"snt": { "type": "text", "analyzer": "standard","fielddata":"true"} #,"store":"true"
 		  }
 		}
@@ -473,9 +476,9 @@ if __name__ == "__main__":
 	#print ( sql("select lem, count(*) cnt  from gzjc where type = 'tok' and pos != 'PUNCT' group by lem order by cnt desc limit 10"))
 	#print ( sqlrow("show tables")) 
 	#print (hybchunk(index='clec')) 
-	init("test")
-	testana()
-
+	#init("test")
+	fire.Fire(init) 
+	
 '''
 {'tokens': [{'token': 'booked', 'start_offset': 0, 'end_offset': 22, 'type': 'word', 'position': 0}, 
 {'token': 'd', 'start_offset': 0, 'end_offset': 22, 'type': 'word', 'position': 0}, 
