@@ -1,6 +1,6 @@
 #from uvirun import * 
 #uvicorn uvirun:app --port 80 --host 0.0.0.0 --reload
-import json,os,uvicorn,time, fastapi,platform,requests,math,re
+import json,os,uvicorn,time, fastapi,platform,requests,math,re,sys
 import numpy as np
 import pandas as pd
 from collections import Counter,defaultdict
@@ -23,6 +23,8 @@ tags_metadata = [ # https://fastapi.tiangolo.com/tutorial/metadata/
 ]
 
 app = globals().get('app', fastapi.FastAPI(openapi_tags=tags_metadata)) #app=FastAPI(title= "Essay Dsk Data API",description= "data for ***",version= "0.1.0",openapi_url="/fastapi/data_manger.json",docs_url="/fastapi/docs",redoc_url="/fastapi/redoc")
+from fastapi.middleware.cors import CORSMiddleware  #https://fastapi.tiangolo.com/zh/tutorial/cors/
+app.add_middleware(CORSMiddleware, allow_origins=['*'], allow_credentials=True, allow_methods=["*"], allow_headers=["*"],)
 now	= lambda: time.strftime('%Y.%m.%d %H:%M:%S',time.localtime(time.time()))
 from util import likelihood
 
