@@ -31,6 +31,7 @@ def wordvec_vec(words:list, name:str="glove-wiki-gigaword-300"):
 
 @app.post('/gensim/pca_xy', tags=["gensim"])
 def pca_xy(words:list=["niche","table"], name:str="glove-wiki-gigaword-300"):  
+	''' TSNE '''
 	from sklearn.decomposition import PCA   #https://blog.csdn.net/qy20115549/article/details/86316974
 	if not hasattr(pca_xy, 'word_xy'): 
 		pca = PCA(n_components=2)
@@ -375,7 +376,7 @@ def distance(w0:str='apple', w1:str='dog', name:str="glove-wiki-gigaword-300"):
 def words_distance(words:list=["orange","banana"], src:str='apple', name:str="glove-wiki-gigaword-300"):
 	''' ["orange","banana"] '''
 	model = _model(name)
-	return [{"word":w, "distance": model.distance(src, w).tolist()} for w in words ]
+	return [{"word":w, "distance": model.distance(src, w).tolist()} for w in words if w in model ]
 
 @app.post('/gensim/n_similarity', tags=["gensim"])
 def n_similarity(dual:list=[["woman", "king"] , ["man"]], name:str="glove-wiki-gigaword-300"): 
